@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,59 +54,20 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 1
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     NORMAL_T = 258,
-     IDE_T = 259,
-     ITERATION_T = 260,
-     RELOP = 261,
-     STRING_CONST = 262,
-     NUM_CONST = 263,
-     BOOL_CONST = 264,
-     SKELITEMTYPE_T = 265,
-     OPTVAL_T = 266,
-     IF_T = 267,
-     THEN_T = 268,
-     ELSE_T = 269,
-     ELSEIF_T = 270,
-     ENDIF_T = 271,
-     AND_T = 272,
-     OR_T = 273,
-     NOT_T = 274
-   };
-#endif
-/* Tokens.  */
-#define NORMAL_T 258
-#define IDE_T 259
-#define ITERATION_T 260
-#define RELOP 261
-#define STRING_CONST 262
-#define NUM_CONST 263
-#define BOOL_CONST 264
-#define SKELITEMTYPE_T 265
-#define OPTVAL_T 266
-#define IF_T 267
-#define THEN_T 268
-#define ELSE_T 269
-#define ELSEIF_T 270
-#define ENDIF_T 271
-#define AND_T 272
-#define OR_T 273
-#define NOT_T 274
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 1 "parser.yy"
 
 /*
@@ -166,6 +126,9 @@ static TypeEnv typeEnv;
 
 
 
+/* Line 189 of yacc.c  */
+#line 131 "parser.cc"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -184,10 +147,61 @@ static TypeEnv typeEnv;
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     NORMAL_T = 258,
+     IDE_T = 259,
+     ITERATION_T = 260,
+     RELOP = 261,
+     STRING_CONST = 262,
+     NUM_CONST = 263,
+     BOOL_CONST = 264,
+     SKELITEMTYPE_T = 265,
+     OPTVAL_T = 266,
+     IF_T = 267,
+     THEN_T = 268,
+     ELSE_T = 269,
+     ELSEIF_T = 270,
+     ENDIF_T = 271,
+     AND_T = 272,
+     OR_T = 273,
+     NOT_T = 274
+   };
+#endif
+/* Tokens.  */
+#define NORMAL_T 258
+#define IDE_T 259
+#define ITERATION_T 260
+#define RELOP 261
+#define STRING_CONST 262
+#define NUM_CONST 263
+#define BOOL_CONST 264
+#define SKELITEMTYPE_T 265
+#define OPTVAL_T 266
+#define IF_T 267
+#define THEN_T 268
+#define ELSE_T 269
+#define ELSEIF_T 270
+#define ENDIF_T 271
+#define AND_T 272
+#define OR_T 273
+#define NOT_T 274
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 58 "parser.yy"
 {
+
+/* Line 214 of yacc.c  */
+#line 58 "parser.yy"
+
   int tok ; /* command */
   char * string ; /* string : id, ... */
   bool boolean ;
@@ -201,13 +215,15 @@ typedef union YYSTYPE
   class Expression *expression;
   class UnaryExpression *unaryexpression;
   class BinaryExpression *binaryexpression;
-}
-/* Line 187 of yacc.c.  */
-#line 207 "parser.cc"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 223 "parser.cc"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 #if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
@@ -227,8 +243,8 @@ typedef struct YYLTYPE
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 232 "parser.cc"
+/* Line 264 of yacc.c  */
+#line 248 "parser.cc"
 
 #ifdef short
 # undef short
@@ -303,14 +319,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -392,9 +408,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-    YYLTYPE yyls;
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+  YYLTYPE yyls_alloc;
 };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
@@ -429,12 +445,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -839,17 +855,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep, yylocationp)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -884,11 +903,11 @@ yy_reduce_print (yyvsp, yylsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       , &(yylsp[(yyi + 1) - (yynrhs)])		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1170,10 +1189,8 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1189,23 +1206,23 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
+/* Location data for the lookahead symbol.  */
+YYLTYPE yylloc;
+
 /* Number of syntax errors so far.  */
 int yynerrs;
-/* Location data for the look-ahead symbol.  */
-YYLTYPE yylloc;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1229,14 +1246,49 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+       `yyls': related to locations.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    /* The location stack.  */
+    YYLTYPE yylsa[YYINITDEPTH];
+    YYLTYPE *yyls;
+    YYLTYPE *yylsp;
+
+    /* The locations where the error started and ended.  */
+    YYLTYPE yyerror_range[2];
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+  YYLTYPE yyloc;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1244,63 +1296,37 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-  /* The location stack.  */
-  YYLTYPE yylsa[YYINITDEPTH];
-  YYLTYPE *yyls = yylsa;
-  YYLTYPE *yylsp;
-  /* The locations where the error started and ended.  */
-  YYLTYPE yyerror_range[2];
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N), yylsp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-  YYLTYPE yyloc;
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yyls = yylsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
   yylsp = yyls;
+
 #if YYLTYPE_IS_TRIVIAL
   /* Initialize the default location before parsing starts.  */
   yylloc.first_line   = yylloc.last_line   = 1;
-  yylloc.first_column = yylloc.last_column = 0;
+  yylloc.first_column = yylloc.last_column = 1;
 #endif
 
   goto yysetstate;
@@ -1339,6 +1365,7 @@ yyparse ()
 		    &yyvs1, yysize * sizeof (*yyvsp),
 		    &yyls1, yysize * sizeof (*yylsp),
 		    &yystacksize);
+
 	yyls = yyls1;
 	yyss = yyss1;
 	yyvs = yyvs1;
@@ -1360,9 +1387,9 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-	YYSTACK_RELOCATE (yyls);
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
+	YYSTACK_RELOCATE (yyls_alloc, yyls);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1383,6 +1410,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1391,16 +1421,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1432,20 +1462,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1486,6 +1512,8 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 95 "parser.yy"
     {
          skel_items = (yyvsp[(1) - (1)].skelitems);
@@ -1493,6 +1521,8 @@ yyreduce:
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 101 "parser.yy"
     {
          (yyval.skelitems) = new SkelItems;
@@ -1501,6 +1531,8 @@ yyreduce:
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 106 "parser.yy"
     {
          (yyvsp[(1) - (2)].skelitems)->add_item ((yyvsp[(2) - (2)].skelitemstruct));
@@ -1509,31 +1541,43 @@ yyreduce:
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 112 "parser.yy"
     { (yyval.skelitemstruct) = (yyvsp[(1) - (1)].normaltext); }
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 113 "parser.yy"
     { (yyval.skelitemstruct) = (yyvsp[(1) - (1)].varitem); }
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 114 "parser.yy"
     { (yyval.skelitemstruct) = (yyvsp[(1) - (1)].ifstruct); }
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 117 "parser.yy"
     { (yyval.skelitems) = (yyvsp[(1) - (1)].skelitems); }
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 118 "parser.yy"
     { (yyval.skelitems) = new SkelItems; }
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 122 "parser.yy"
     {
                (yyval.normaltext) = skel_factory->createNormalText ((yyvsp[(1) - (1)].string));
@@ -1541,6 +1585,8 @@ yyreduce:
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 128 "parser.yy"
     {
              // const skelitem_type &type = checkType($2, "");
@@ -1550,6 +1596,8 @@ yyreduce:
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 134 "parser.yy"
     {
              //checkType($2, $4);
@@ -1559,6 +1607,8 @@ yyreduce:
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 140 "parser.yy"
     {
              //checkType($2, $4);
@@ -1570,6 +1620,8 @@ yyreduce:
     break;
 
   case 15:
+
+/* Line 1455 of yacc.c  */
 #line 153 "parser.yy"
     {
               (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), 0);
@@ -1577,6 +1629,8 @@ yyreduce:
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 157 "parser.yy"
     {
               (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), (yyvsp[(5) - (5)].ifstruct));
@@ -1584,6 +1638,8 @@ yyreduce:
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 163 "parser.yy"
     {
                (yyval.ifstruct) = new IfStruct(0, (yyvsp[(2) - (3)].skelitems));
@@ -1591,6 +1647,8 @@ yyreduce:
     break;
 
   case 18:
+
+/* Line 1455 of yacc.c  */
 #line 167 "parser.yy"
     {
                (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), 0);
@@ -1598,6 +1656,8 @@ yyreduce:
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 171 "parser.yy"
     {
                (yyval.ifstruct) = new IfStruct((yyvsp[(2) - (5)].expression), (yyvsp[(4) - (5)].skelitems), (yyvsp[(5) - (5)].ifstruct));
@@ -1605,21 +1665,29 @@ yyreduce:
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 181 "parser.yy"
     { (yyval.expression) = new BinaryExpression( (yyvsp[(1) - (3)].expression)->getText() + " " + ANDOP + " " + (yyvsp[(3) - (3)].expression)->getText(), ANDOP, (yyvsp[(1) - (3)].expression), (yyvsp[(3) - (3)].expression)) ; }
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 183 "parser.yy"
     { (yyval.expression) = new BinaryExpression( (yyvsp[(1) - (3)].expression)->getText() + " " + OROP + " " + (yyvsp[(3) - (3)].expression)->getText(), OROP, (yyvsp[(1) - (3)].expression), (yyvsp[(3) - (3)].expression)) ; }
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 188 "parser.yy"
     { (yyval.expression) = new BinaryExpression( (yyvsp[(1) - (3)].expression)->getText() + " " + (yyvsp[(2) - (3)].string) + " " + (yyvsp[(3) - (3)].expression)->getText(), (yyvsp[(2) - (3)].string), (yyvsp[(1) - (3)].expression), (yyvsp[(3) - (3)].expression)) ; }
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 192 "parser.yy"
     {
           	   // const skelitem_type &type = checkType($1, "");
@@ -1629,6 +1697,8 @@ yyreduce:
     break;
 
   case 27:
+
+/* Line 1455 of yacc.c  */
 #line 198 "parser.yy"
     {
           	   // checkType($1, $3);
@@ -1638,33 +1708,44 @@ yyreduce:
     break;
 
   case 28:
+
+/* Line 1455 of yacc.c  */
 #line 204 "parser.yy"
     { (yyval.expression) = new Expression((yyvsp[(1) - (1)].string), STRING_TYPE); (yyval.expression)->setInfo((yylsp[(1) - (1)]).first_line); (yyval.expression)->setIsConst(true); }
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 206 "parser.yy"
     { (yyval.expression) = new Expression((yyvsp[(1) - (1)].string), INT_TYPE); (yyval.expression)->setInfo((yylsp[(1) - (1)]).first_line); (yyval.expression)->setIsConst(true); }
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 208 "parser.yy"
     { (yyval.expression) = new Expression((yyvsp[(1) - (1)].string), BOOL_TYPE); (yyval.expression)->setInfo((yylsp[(1) - (1)]).first_line); (yyval.expression)->setIsConst(true); }
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 209 "parser.yy"
     { (yyval.expression) = (yyvsp[(2) - (3)].expression); }
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 211 "parser.yy"
     { (yyval.expression) = new UnaryExpression(string() + NOTOP + " " + (yyvsp[(2) - (2)].expression)->getText(), NOTOP, (yyvsp[(2) - (2)].expression)); }
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1668 "parser.cc"
+
+/* Line 1455 of yacc.c  */
+#line 1749 "parser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1740,7 +1821,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1757,7 +1838,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1815,14 +1896,11 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
   yyerror_range[1] = yylloc;
   /* Using YYLLOC is tempting, but would change the location of
-     the look-ahead.  YYLOC is available though.  */
+     the lookahead.  YYLOC is available though.  */
   YYLLOC_DEFAULT (yyloc, (yyerror_range - 1), 2);
   *++yylsp = yyloc;
 
@@ -1847,7 +1925,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1858,7 +1936,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval, &yylloc);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1884,6 +1962,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 214 "parser.yy"
 
 
